/* Copyright (c) Nordic Semiconductor ASA
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 *   1. Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * 
 *   2. Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 * 
 *   3. Neither the name of Nordic Semiconductor ASA nor the names of other
 *   contributors to this software may be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 * 
 *   4. This software must only be used in a processor manufactured by Nordic
 *   Semiconductor ASA, or in a processor manufactured by a third party that
 *   is used in combination with a processor manufactured by Nordic Semiconductor.
 * 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef OUR_SERVICE_H__
#define OUR_SERVICE_H__

#include <stdint.h>
#include "ble.h"
#include "ble_srv_common.h"

// FROM_SERVICE_TUTORIAL: Defining 16-bit service and 128-bit base UUIDs
//C821F00D-988B-43E9-BE62-CF8F6BB366BB
#define BLE_UUID_LUCKA_BASE             {{0xBB, 0x66, 0xB3, 0x6B, 0x8F, 0xCF, 0x62, 0xBE, 0xE9, 0x43, 0x8B, 0x98, 0x00, 0x00, 0x21, 0xC8}} // 128-bit base UUID
#define BLE_UUID_LUCKA_SERVICE            0xF00D // Just a random, but recognizable value

// ALREADY_DONE_FOR_YOU: Defining 16-bit characteristic UUID
#define BLE_UUID_LUCKA_CHAR_STATE      0xBEEF // Just a random, but recognizable value
#define BLE_UUID_LUCKA_CHAR_FREQ       0xB00B
#define BLE_UUID_LUCKA_CHAR_TIMER      0xFACE
#define BLE_UUID_LUCKA_CHAR_VOLTAGE    0xABBA
#define BLE_UUID_LUCKA_CHAR_MODE       0xBABA
#define BLE_UUID_LUCKA_CHAR_CMD				 0xBABE

#define LASER_OFF	      1		
#define LASER_ON				2
#define LASER_SLEEP			3

#define ONOFF_SWITCH 	1
#define ON_SWITCH			2

#define RESET_FREQUENCY		11
#define RESET_TIME				60	
#define RESET_MODE 				1
/**
 * @brief This structure contains various status information for our service. 
 * It only holds one entry now, but will be populated with more items as we go.
 * The name is based on the naming convention used in Nordic's SDKs. 
 * 'ble indicates that it is a Bluetooth Low Energy relevant structure and 
 * os is short for Our Service). 
 */
typedef struct
{
	  uint16_t    								conn_handle;    		/**< Handle of the current connection (as provided by the BLE stack, is BLE_CONN_HANDLE_INVALID if not in a connection).*/
    uint16_t    								service_handle;     /**< Handle of Our Service (as provided by the BLE stack). */
	  ble_gatts_char_handles_t    char_handles_state;
	  ble_gatts_char_handles_t    char_handles_freq;
		ble_gatts_char_handles_t    char_handles_time;
    ble_gatts_char_handles_t    char_handles_voltage;
	  ble_gatts_char_handles_t    char_handles_mode;
		ble_gatts_char_handles_t    char_handles_cmd;
}ble_lus_t;

extern uint8_t 	char_State,
								char_Time,
								char_Voltage;

/**@brief Function for handling BLE Stack events related to our service and characteristic.
 *
 * @details Handles all events from the BLE stack of interest to Our Service.
 *
 * @param[in]   p_our_service       Our Service structure.
 * @param[in]   p_ble_evt  Event received from the BLE stack.
 */
void ble_lucka_service_on_ble_evt(ble_lus_t * p_lucka_service, ble_evt_t * p_ble_evt);

/**@brief Function for initializing our new service.
 *
 * @param[in]   p_our_service       Pointer to Our Service structure.
 */
void lucka_service_init(ble_lus_t * p_our_service);

/**@brief Function for updating and sending new characteristic values
 *
 * @details The application calls this function whenever our timer_timeout_handler triggers
 *
 * @param[in]   p_our_service                     Our Service structure.
 * @param[in]   characteristic_value     New characteristic value.
 */
void lucka_state_char_update(ble_lus_t *p_lus, uint8_t state);

#endif  /* _ OUR_SERVICE_H__ */
